from django.contrib.staticfiles import finders
from django.conf import settings


def add_ignores(ignore_patterns):
    ignore = settings.STATICFILES_FINDERS_IGNORE

    if ignore:
        if ignore_patterns:
            ignore_patterns.extend(ignore)
        else:
            ignore_patterns = ignore

    return ignore_patterns


class FileSystemFinder(finders.FileSystemFinder):
    def list(self, ignore_patterns):
        return super(FileSystemFinder, self).list(add_ignores(ignore_patterns))



from distutils.core import setup

import advanced_staticfinder

setup(
    name = "django_advanced_staticfinder",
    version = advanced_staticfinder.__version__,
    description = "Menu helpers for django projects",
    url = "https://bitbucket.org/megatyumen/django_advanced_staticfinder",
    author = "Alrusdi",
    author_email = "alrusdi@gmail.com",
    packages = [
        "advanced_staticfinder",
    ],
    package_data = {
        "advanced_staticfinder": [
            "advanced_staticfinder/*",
        ],
    },
    long_description = open("README.rst").read(),
    classifiers = [
        'Programming Language :: Python',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Framework :: Django',
    ],
)

